#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Crée le Déc 17  2022

@auteur: David ALBERTO
(www.astrolabe-science.fr)
"""
"""
Ce code récupère les symboles, lignes et colonnes du tableau périodique
pour les éléments chimiques demandés, ainsi que les valeurs d'une
donnée à choisir parmi : (liste non exhaustive, voir documentation du module mendeleev) :
    
abundance_crust (mg/kg)     abundance_sea (mg/L)        atomic_radius (pm)
atomic_volume               boiling_point               melting_point
evaporation_heat            fusion_heat                 heat_of_formation
ionenergy                   is_radioactive (booléen)    lattice_constant
metallic_radius             specific_heat               thermal_conductivity (W/(mK))
vdw_radius

Ces données sont exportées dans un fichier csv.
"""
import numpy as np#pour remplacer les valeurs absentes par 'NaN' (Not a Number)
from mendeleev import element
import pandas as pd

Zmax=118#on peut limiter aux premiers éléments chimiques
liste_Z = np.arange(1,Zmax+1)
NomFichier = 'donnees_' + 'isotopes' + '.csv'

"""
La ligne est la donnee de la période de l'élément.
La colonne est la donnee du paramètre "group_id" de l'élément.
Pour les terres rares, le module ne fournit pas de donnee pour "group_id" ; 
je me base donc sur la donnee de Z pour établir un numéro de colonne.
"""
y_offset_TR = 3# décalage de lignes vers le bas pour les terres rares


def valeur(Z):
    """
    Z : entier : numéro atomique de l'élément
    -------
    symbole : string
    colonne : entier.N° de colonne dans le tableau périodique
    ligne : entier. N° de ligne dans le TP
    donnee : la donnée sélectionnée (flottant, ou entier, ou string, ou booléen, selon)
    """
    Z = int(Z)
    symbole = element(Z).symbol
    # donnee=element(Z).electronegativity('pauling')
    # donnee=element(Z).electron_affinity
    # donnee=element(Z).ionenergies[1]#énergie d'ionisation (eV)(Zmax=108)
    # donnee=element(Z).atomic_radius
    donnee=len(element(Z).isotopes)
    if donnee is None:
        donnee='NaN'
    if Z>=58 and Z<=71:#lanthanides
        colonne = 2+Z-57
        ligne = element(Z).period+y_offset_TR
    elif Z>=90 and Z<=103:#actinides
        colonne = 2+Z-89
        ligne = element(Z).period+y_offset_TR
    else:
        colonne = element(Z).group_id
        ligne = element(Z).period
    return symbole, colonne, ligne, donnee
# ------------------------------ Fin de la fonction

valeur_vect = np.vectorize(valeur)# vectorization de la fonction, pour qu'elle soit applicable à une liste de valeurs.

symbole, colonne, ligne, valeur = valeur_vect(liste_Z)

#  création d'un tableau (dataframe du module pandas)
df=pd.DataFrame({'col':colonne,
                  'lig':ligne,
                  'symbole':symbole,
                  'valeur': valeur})

df.to_csv(NomFichier,
          sep='\t',# séparateur de colonne : tabulation
          index=False,# supprime l'index
          na_rep='NaN'# remplace les données vides par 'NaN' (lisible par LaTeX pgfplots)
          )
